@@ -85,7 +85,7 @@ shutdown(Pid) ->
 %% ------------------------------------------------------------------
 
 init([ConnInfo, ConnCfg]) ->
-    {ok, Pid} = s1ap_proxy:start_link(),
+    {ok, Pid} = s1ap_proxy:start_link(ConnInfo),
     {ok, connecting,
      #{enb_aid => maps:get(aid, ConnInfo),
        conn_cfg => ConnCfg,
